==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/elements/te0552.f <==
      SUBROUTINE TE0552(OPTION,NOMTE)
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 29/04/2004   AUTEUR JMBHH01 J.M.PROIX 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================
      IMPLICIT REAL*8 (A-H,O-Z)
      CHARACTER*16 OPTION,NOMTE

C----------------------------------------------------------------------
C FONCTION REALISEE: CALCUL DE LA DURETE ASSOCIEE A LA METALLURGIE
C                    EN 3D
C OPTION : 'DURT_ELGA_META' ET 'DURT_ELNO_META'
C - ARGUMENTS:
C        DONNEES:      OPTION       -->  OPTION DE CALCUL
C                      NOMTE        -->  NOM DU TYPE ELEMENT
C----------------------------------------------------------------------
C --------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ---------------------

      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)

C --------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ---------------------

      CHARACTER*24 NOMRES(5)
      CHARACTER*2 CODRET(5)

      REAL*8 PHASE(5),VALRES(5),ZALPHA,DURTPG(27)
      INTEGER JGANO,NNO,IPOIDS,MATOS,IMATE


      CALL JEMARQ()

      CALL ELREF4(' ','RIGI',NDIM,NNO,NNOS,NPG1,IPOIDS,IVF,IDFDE,JGANO)
      DO 10 I = 1,1
   10 CONTINUE



      CALL JEVECH('PMATERC','L',IMATE)
      CALL JEVECH('PPHASIN','L',IPHASI)
      CALL JEVECH('PDURT_R','E',IDURT)
      MATOS = ZI(IMATE)

      DO 40 KP = 1,NPG1

C----RECUPERATION DES CARACTERISTIQUES
        NOMRES(1) = 'F1_DURT'
        NOMRES(2) = 'F2_DURT'
        NOMRES(3) = 'F3_DURT'
        NOMRES(4) = 'F4_DURT'
        NOMRES(5) = 'C_DURT'
        CALL RCVALA(MATOS,' ','DURT_META',1,'TEMP',0.D0,5,NOMRES,VALRES,
     &              CODRET,'F')


C----RECUPERATION Z POUR CHAQUE PHASE
        ZALPHA = 0.D0
        DO 20 I = 1,4
          PHASE(I) = ZR(IPHASI+7* (KP-1)+I-1)
          ZALPHA = ZALPHA + PHASE(I)
   20   CONTINUE
        PHASE(5) = 1 - ZALPHA

C----CALCUL DE LA DURETE ----------------------------------------------

        DURTPG(1+ (KP-1)) = 0.D0
        DO 30 I = 1,5
          DURTPG(1+ (KP-1)) = DURTPG(1+ (KP-1)) + PHASE(I)*VALRES(I)
   30   CONTINUE
        IF (OPTION.EQ.'DURT_ELGA_META') THEN
          ZR(IDURT+ (KP-1)) = DURTPG(1+ (KP-1))
        END IF
   40 CONTINUE

      IF (OPTION.EQ.'DURT_ELNO_META') THEN
        CALL PPGAN2(JGANO,1,DURTPG,ZR(IDURT))
      END IF

   50 CONTINUE
      CALL JEDEMA()
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/elements/te0552.f <==
      SUBROUTINE TE0552(OPTION,NOMTE)
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 04/04/2005   AUTEUR CIBHHPD L.SALMONA 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================
      IMPLICIT REAL*8 (A-H,O-Z)
      CHARACTER*16 OPTION,NOMTE

C----------------------------------------------------------------------
C FONCTION REALISEE: CALCUL DE LA DURETE ASSOCIEE A LA METALLURGIE
C                    EN 3D
C OPTION : 'DURT_ELGA_META' ET 'DURT_ELNO_META'
C - ARGUMENTS:
C        DONNEES:      OPTION       -->  OPTION DE CALCUL
C                      NOMTE        -->  NOM DU TYPE ELEMENT
C----------------------------------------------------------------------
C --------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ---------------------

      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)

C --------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ---------------------

      CHARACTER*24 NOMRES(5)
      CHARACTER*2 CODRET(5)

      REAL*8 PHASE(5),VALRES(5),ZALPHA,DURTNO
      INTEGER JGANO,NNO,IPOIDS,MATOS,IMATE,KN


      CALL JEMARQ()

      CALL ELREF4(' ','RIGI',NDIM,NNO,NNOS,NPG1,IPOIDS,IVF,IDFDE,JGANO)
      DO 10 I = 1,1
   10 CONTINUE



      CALL JEVECH('PMATERC','L',IMATE)
      CALL JEVECH('PPHASIN','L',IPHASI)
      CALL JEVECH('PDURT_R','E',IDURT)
      MATOS = ZI(IMATE)
      DO 40 KN = 1,NNO

C----RECUPERATION DES CARACTERISTIQUES
        NOMRES(1) = 'F1_DURT'
        NOMRES(2) = 'F2_DURT'
        NOMRES(3) = 'F3_DURT'
        NOMRES(4) = 'F4_DURT'
        NOMRES(5) = 'C_DURT'
        CALL RCVALA(MATOS,' ','DURT_META',1,'TEMP',0.D0,5,NOMRES,VALRES,
     &              CODRET,'F')


C----RECUPERATION Z POUR CHAQUE PHASE
        ZALPHA = 0.D0
        DO 20 I = 1,4
          PHASE(I) = ZR(IPHASI+7* (KN-1)+I-1)
          ZALPHA = ZALPHA + PHASE(I)
   20   CONTINUE
        PHASE(5) = 1 - ZALPHA

C----CALCUL DE LA DURETE ----------------------------------------------

        DURTNO = 0.D0
        DO 30 I = 1,5
          DURTNO = DURTNO + PHASE(I)*VALRES(I)
   30   CONTINUE
        ZR(IDURT+ (KN-1)) = DURTNO

   40 CONTINUE




      CALL JEDEMA()
      END
